@@ -69,8 +69,8 @@ def compare_companies(org_name_messy, org_name_clean, threshold = SIMILARITY_DIS
     # n_jobs is set to run to allow process to run in parallel using all processors
 
     nbrs = NearestNeighbors(n_neighbors=1,
-                           # metric='cosine',
-                           # algorithm='brute',
+                            metric='cosine',
+                            algorithm='brute',
                             n_jobs=-1).fit(tfidf)
 
     
